Struct async_prost::AsyncProstStream [−][src]
A wrapper around an async stream that receives and sends prost-encoded values
Implementations
impl<S, R, W, D> AsyncProstStream<S, R, W, D>[src]
pub fn get_ref(&self) -> &S[src]
Gets a reference to the underlying stream.
It is inadvisable to directly read from or write to the underlying stream.
pub fn get_mut(&mut self) -> &mut S[src]
Gets a mutable reference to the underlying stream.
It is inadvisable to directly read from or write to the underlying stream.
pub fn into_inner(self) -> S[src]
Unwraps this AsyncProstStream, returning the underlying stream.
Note that any leftover serialized data that has not yet been sent, or received data that has not yet been deserialized, is lost.
impl<S, R, W, D> AsyncProstStream<S, R, W, D>[src]
pub fn for_async(self) -> AsyncProstStream<S, R, W, AsyncDestination>[src]
make this stream include the serialized data’s size before each serialized value
pub fn for_async_framed(
self
) -> AsyncProstStream<S, R, W, AsyncFrameDestination>[src]
self
) -> AsyncProstStream<S, R, W, AsyncFrameDestination>
make this stream include the serialized data’s size before each serialized value
pub fn for_sync(self) -> AsyncProstStream<S, R, W, SyncDestination>[src]
Make this stream only send prost-encoded values
impl<R, W, D> AsyncProstStream<TcpStream, R, W, D>[src]
pub fn tcp_split(
&mut self
) -> (AsyncProstReader<ReadHalf<'_>, R, D>, AsyncProstWriter<WriteHalf<'_>, W, D>)[src]
&mut self
) -> (AsyncProstReader<ReadHalf<'_>, R, D>, AsyncProstWriter<WriteHalf<'_>, W, D>)
split a TCP-based stream into a read half and a write half